/****************************************************************************
** Meta object code from reading C++ file 'qabstracttransition.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtscxml/src/statemachine/qabstracttransition.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qabstracttransition.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QAbstractTransitionE_t {};
} // unnamed namespace

template <> constexpr inline auto QAbstractTransition::qt_create_metaobjectdata<qt_meta_tag_ZN19QAbstractTransitionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QAbstractTransition",
        "triggered",
        "",
        "targetStateChanged",
        "targetStatesChanged",
        "sourceState",
        "QState*",
        "targetState",
        "QAbstractState*",
        "targetStates",
        "QList<QAbstractState*>",
        "transitionType",
        "TransitionType",
        "ExternalTransition",
        "InternalTransition"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'triggered'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetStateChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetStatesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sourceState'
        QtMocHelpers::PropertyData<QState*>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'targetState'
        QtMocHelpers::PropertyData<QAbstractState*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'targetStates'
        QtMocHelpers::PropertyData<QList<QAbstractState*>>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'transitionType'
        QtMocHelpers::PropertyData<enum TransitionType>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Bindable, -1, 0x101),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TransitionType'
        QtMocHelpers::EnumData<enum TransitionType>(12, 12, QMC::EnumFlags{}).add({
            {   13, TransitionType::ExternalTransition },
            {   14, TransitionType::InternalTransition },
        }),
    };
    return QtMocHelpers::metaObjectData<QAbstractTransition, qt_meta_tag_ZN19QAbstractTransitionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QAbstractTransition::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QAbstractTransitionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QAbstractTransitionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QAbstractTransitionE_t>.metaTypes,
    nullptr
} };

void QAbstractTransition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QAbstractTransition *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->triggered(QPrivateSignal()); break;
        case 1: _t->targetStateChanged(QPrivateSignal()); break;
        case 2: _t->targetStatesChanged(QPrivateSignal()); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QAbstractTransition::*)(QPrivateSignal)>(_a, &QAbstractTransition::triggered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractTransition::*)(QPrivateSignal)>(_a, &QAbstractTransition::targetStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractTransition::*)(QPrivateSignal)>(_a, &QAbstractTransition::targetStatesChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QState**>(_v) = _t->sourceState(); break;
        case 1: *reinterpret_cast<QAbstractState**>(_v) = _t->targetState(); break;
        case 2: *reinterpret_cast<QList<QAbstractState*>*>(_v) = _t->targetStates(); break;
        case 3: *reinterpret_cast<enum TransitionType*>(_v) = _t->transitionType(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTargetState(*reinterpret_cast<QAbstractState**>(_v)); break;
        case 2: _t->setTargetStates(*reinterpret_cast<QList<QAbstractState*>*>(_v)); break;
        case 3: _t->setTransitionType(*reinterpret_cast<enum TransitionType*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTransitionType(); break;
        default: break;
        }
    }
}

const QMetaObject *QAbstractTransition::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractTransition::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QAbstractTransitionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QAbstractTransition::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QAbstractTransition::triggered(QPrivateSignal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QAbstractTransition::targetStateChanged(QPrivateSignal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QAbstractTransition::targetStatesChanged(QPrivateSignal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
